@@ -1,10 +1,9 @@
 package Pod::Weaver::Section::Contributors;
-$Pod::Weaver::Section::Contributors::VERSION = '0.008';
+$Pod::Weaver::Section::Contributors::VERSION = '0.009';
 use Moose;
 with 'Pod::Weaver::Role::Section';
 # ABSTRACT: a section listing contributors
 
-use Moose::Autobox;
 use List::MoreUtils 'uniq';
 
 use Pod::Elemental::Element::Nested;
@@ -102,12 +101,12 @@ sub weave_section {
         Pod::Elemental::Element::Pod5::Command->new({
             command => 'over', content => '4',
         }),
-        $result->map(sub {
+        ( map {
             Pod::Elemental::Element::Pod5::Command->new({
                 command => 'item', content => '*',
             }),
             $_,
-        })->flatten,
+        } @$result ),
         Pod::Elemental::Element::Pod5::Command->new({
             command => 'back', content => '',
         }),
@@ -133,17 +132,16 @@ sub weave_section {
     #
 
     if ( $self->head ) {
-        $document->children->push(
+        push @{ $document->children },
             Pod::Elemental::Element::Nested->new({
                 type     => 'command',
                 command  => 'head' . $self->head,
                 content  => $name,
                 children => $result,
-            }),
-        );
+            });
     }
     else {
-        $document->children->push($_) for @$result;
+        push @{ $document->children }, @$result;
     }
 }
 
@@ -162,7 +160,7 @@ Pod::Weaver::Section::Contributors - a section listing contributors
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -278,6 +276,8 @@ Keedi Kim - 김도형 <keedi@cpan.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords carandraug - Carnë Draug (cpan: CDRAUG) ether Karen Etheridge ETHER) thaljef Jeffrey Ryan Thalhammer THALJEF)
+
 =over 4
 
 =item *
